# RAFT

## Original code

[https://github.com/princeton-vl/RAFT](https://github.com/princeton-vl/RAFT)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{teed2020raft,
  title={Raft: Recurrent all-pairs field transforms for optical flow},
  author={Teed, Zachary and Deng, Jia},
  booktitle={European Conference on Computer Vision},
  pages={402--419},
  year={2020},
  organization={Springer}
}
```